@@ -19,6 +19,7 @@ from shadowstep.element.properties import ElementProperties
 from shadowstep.element.screenshots import ElementScreenshots
 from shadowstep.element.utilities import ElementUtilities
 from shadowstep.element.waiting import ElementWaiting
+from shadowstep.enums import GestureStrategy
 from shadowstep.locator import UiSelector
 from shadowstep.utils.utils import get_current_func_name
 
@@ -30,7 +31,6 @@ if TYPE_CHECKING:
     from shadowstep.element.should import Should
     from shadowstep.shadowstep import Shadowstep
 
-
 # Configure the root logger (basic configuration)
 logging.basicConfig(
     level=logging.INFO,
@@ -367,183 +367,263 @@ class Element(ElementBase):
         return self.gestures.tap_and_move(locator, x, y, direction, distance)
 
     @fail_safe_element()
-    def click(self, duration: int | None = None) -> Element:
+    def click(
+        self,
+        duration: int | None = None,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Click the element.
 
         Args:
             duration: Duration of the click in milliseconds.
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.gestures.click(duration)
+        return self.gestures.click(duration, strategy)
 
     @fail_safe_element()
-    def click_double(self) -> Element:
+    def double_click(
+        self,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Perform a double click on the element.
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.gestures.click_double()
+        return self.gestures.double_click(strategy)
 
     @fail_safe_element()
-    def drag(self, end_x: int, end_y: int, speed: int = 2500) -> Element:
+    def drag(
+        self,
+        end_x: int,
+        end_y: int,
+        speed: int = 2500,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Drag the element to target coordinates.
 
         Args:
             end_x: Target X coordinate.
             end_y: Target Y coordinate.
             speed: Drag speed in pixels per second (default: 2500).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.gestures.drag(end_x, end_y, speed)
+        return self.gestures.drag(end_x, end_y, speed, strategy)
 
-    def fling_up(self, speed: int = 2500) -> Element:
+    def fling_up(
+        self,
+        speed: int = 2500,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Perform a fling gesture upward on the element.
 
         Args:
             speed: Fling speed in pixels per second (default: 2500).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.fling(speed=speed, direction="up")
+        return self.fling(speed=speed, direction="up", strategy=strategy)
 
-    def fling_down(self, speed: int = 2500) -> Element:
+    def fling_down(
+        self,
+        speed: int = 2500,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Perform a fling gesture downward on the element.
 
         Args:
             speed: Fling speed in pixels per second (default: 2500).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.fling(speed=speed, direction="down")
+        return self.fling(speed=speed, direction="down", strategy=strategy)
 
-    def fling_left(self, speed: int = 2500) -> Element:
+    def fling_left(
+        self,
+        speed: int = 2500,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Perform a fling gesture leftward on the element.
 
         Args:
             speed: Fling speed in pixels per second (default: 2500).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.fling(speed=speed, direction="left")
+        return self.fling(speed=speed, direction="left", strategy=strategy)
 
-    def fling_right(self, speed: int = 2500) -> Element:
+    def fling_right(
+        self,
+        speed: int = 2500,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Perform a fling gesture rightward on the element.
 
         Args:
             speed: Fling speed in pixels per second (default: 2500).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.fling(speed=speed, direction="right")
+        return self.fling(speed=speed, direction="right", strategy=strategy)
 
     @fail_safe_element()
-    def fling(self, speed: int, direction: str) -> Element:
+    def fling(
+        self,
+        speed: int,
+        direction: str,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Perform a fling gesture on the element.
 
         Args:
             speed: Fling speed in pixels per second.
             direction: Direction of fling ("up", "down", "left", "right").
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.gestures.fling(speed, direction)
+        return self.gestures.fling(speed, direction, strategy)
 
     def scroll_down(
         self,
         percent: float = 0.7,
         speed: int = 2000,
         return_bool: bool = False,  # noqa: FBT001, FBT002
-    ) -> Element:
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element | bool:
         """Scroll down within the element.
 
         Args:
             percent: Scroll distance as percentage of element height (default: 0.7).
             speed: Scroll speed in pixels per second (default: 2000).
             return_bool: Whether to return boolean instead of Element (default: False).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
-            Element: Self for method chaining.
+            Element | bool: Self for method chaining or boolean if return_bool is True.
 
         """
-        return self.scroll(direction="down", percent=percent, speed=speed, return_bool=return_bool)
+        return self.scroll(
+            direction="down",
+            percent=percent,
+            speed=speed,
+            return_bool=return_bool,
+            strategy=strategy,
+        )
 
     def scroll_up(
         self,
         percent: float = 0.7,
         speed: int = 2000,
         return_bool: bool = False,  # noqa: FBT001, FBT002
-    ) -> Element:
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element | bool:
         """Scroll up within the element.
 
         Args:
             percent: Scroll distance as percentage of element height (default: 0.7).
             speed: Scroll speed in pixels per second (default: 2000).
             return_bool: Whether to return boolean instead of Element (default: False).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
-            Element: Self for method chaining.
+            Element | bool: Self for method chaining or boolean if return_bool is True.
 
         """
-        return self.scroll(direction="up", percent=percent, speed=speed, return_bool=return_bool)
+        return self.scroll(
+            direction="up",
+            percent=percent,
+            speed=speed,
+            return_bool=return_bool,
+            strategy=strategy,
+        )
 
     def scroll_left(
         self,
         percent: float = 0.7,
         speed: int = 2000,
         return_bool: bool = False,  # noqa: FBT001, FBT002
-    ) -> Element:
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element | bool:
         """Scroll left within the element.
 
         Args:
             percent: Scroll distance as percentage of element width (default: 0.7).
             speed: Scroll speed in pixels per second (default: 2000).
             return_bool: Whether to return boolean instead of Element (default: False).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
-            Element: Self for method chaining.
+            Element | bool: Self for method chaining or boolean if return_bool is True.
 
         """
-        return self.scroll(direction="left", percent=percent, speed=speed, return_bool=return_bool)
+        return self.scroll(
+            direction="left",
+            percent=percent,
+            speed=speed,
+            return_bool=return_bool,
+            strategy=strategy,
+        )
 
     def scroll_right(
         self,
         percent: float = 0.7,
         speed: int = 2000,
         return_bool: bool = False,  # noqa: FBT001, FBT002
-    ) -> Element:
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element | bool:
         """Scroll right within the element.
 
         Args:
             percent: Scroll distance as percentage of element width (default: 0.7).
             speed: Scroll speed in pixels per second (default: 2000).
             return_bool: Whether to return boolean instead of Element (default: False).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
-            Element: Self for method chaining.
+            Element | bool: Self for method chaining or boolean if return_bool is True.
 
         """
-        return self.scroll(direction="right", percent=percent, speed=speed, return_bool=return_bool)
+        return self.scroll(
+            direction="right",
+            percent=percent,
+            speed=speed,
+            return_bool=return_bool,
+            strategy=strategy,
+        )
 
     @fail_safe_element()
-    def scroll(self, direction: str, percent: float, speed: int, return_bool: bool) -> Element:  # noqa: FBT001
+    def scroll(
+        self,
+        direction: str,
+        percent: float,
+        speed: int,
+        return_bool: bool,  # noqa: FBT001
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element | bool:
         """Scroll within the element in specified direction.
 
         Args:
@@ -551,153 +631,215 @@ class Element(ElementBase):
             percent: Scroll distance as percentage of element size.
             speed: Scroll speed in pixels per second.
             return_bool: Whether to return boolean instead of Element.
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
-            Element: Self for method chaining.
+            Element | bool: Self for method chaining or boolean if return_bool is True.
 
         """
-        return self.gestures.scroll(direction, percent, speed, return_bool)
+        return self.gestures.scroll(direction, percent, speed, return_bool, strategy)
 
     @fail_safe_element()
-    def scroll_to_bottom(self, percent: float = 0.7, speed: int = 8000) -> Element:
+    def scroll_to_bottom(
+        self,
+        percent: float = 0.7,
+        speed: int = 8000,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Scroll to the bottom of the element.
 
         Args:
             percent: Scroll distance as percentage of element height (default: 0.7).
             speed: Scroll speed in pixels per second (default: 8000).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.gestures.scroll_to_bottom(percent, speed)
+        return self.gestures.scroll_to_bottom(percent, speed, strategy)
 
     @fail_safe_element()
-    def scroll_to_top(self, percent: float = 0.7, speed: int = 8000) -> Element:
+    def scroll_to_top(
+        self,
+        percent: float = 0.7,
+        speed: int = 8000,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Scroll to the top of the element.
 
         Args:
             percent: Scroll distance as percentage of element height (default: 0.7).
             speed: Scroll speed in pixels per second (default: 8000).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.gestures.scroll_to_top(percent, speed)
+        return self.gestures.scroll_to_top(percent, speed, strategy)
 
     @fail_safe_element()
     def scroll_to_element(
         self,
         locator: tuple[str, str] | dict[str, Any] | Element | UiSelector,
         max_swipes: int = 30,
+        percent: float = 0.7,
+        speed: int = 5000,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
     ) -> Element:
         """Scroll to find and return a specific element.
 
         Args:
             locator: Element locator to search for.
             max_swipes: Maximum number of swipe attempts (default: 30).
+            percent: Scroll distance as percentage of element size (default: 0.7).
+            speed: Scroll speed in pixels per second (default: 5000).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Found element instance.
 
         """
-        return self.gestures.scroll_to_element(locator, max_swipes)
+        return self.gestures.scroll_to_element(locator, max_swipes, percent, speed, strategy)
 
     @fail_safe_element()
-    def zoom(self, percent: float = 0.75, speed: int = 2500) -> Element:
+    def zoom(
+        self,
+        percent: float = 0.75,
+        speed: int = 2500,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Perform a zoom gesture on the element.
 
         Args:
             percent: Zoom scale as percentage (default: 0.75).
             speed: Zoom speed in pixels per second (default: 2500).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.gestures.zoom(percent, speed)
+        return self.gestures.zoom(percent, speed, strategy)
 
     @fail_safe_element()
-    def unzoom(self, percent: float = 0.75, speed: int = 2500) -> Element:
+    def unzoom(
+        self,
+        percent: float = 0.75,
+        speed: int = 2500,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Perform an unzoom gesture on the element.
 
         Args:
             percent: Unzoom scale as percentage (default: 0.75).
             speed: Unzoom speed in pixels per second (default: 2500).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.gestures.unzoom(percent, speed)
+        return self.gestures.unzoom(percent, speed, strategy)
 
-    def swipe_up(self, percent: float = 0.75, speed: int = 5000) -> Element:
+    def swipe_up(
+        self,
+        percent: float = 0.75,
+        speed: int = 5000,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Perform a swipe up gesture on the element.
 
         Args:
             percent: Swipe distance as percentage of element height (default: 0.75).
             speed: Swipe speed in pixels per second (default: 5000).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.swipe(direction="up", percent=percent, speed=speed)
+        return self.swipe(direction="up", percent=percent, speed=speed, strategy=strategy)
 
-    def swipe_down(self, percent: float = 0.75, speed: int = 5000) -> Element:
+    def swipe_down(
+        self,
+        percent: float = 0.75,
+        speed: int = 5000,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Perform a swipe down gesture on the element.
 
         Args:
             percent: Swipe distance as percentage of element height (default: 0.75).
             speed: Swipe speed in pixels per second (default: 5000).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.swipe(direction="down", percent=percent, speed=speed)
+        return self.swipe(direction="down", percent=percent, speed=speed, strategy=strategy)
 
-    def swipe_left(self, percent: float = 0.75, speed: int = 5000) -> Element:
+    def swipe_left(
+        self,
+        percent: float = 0.75,
+        speed: int = 5000,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Perform a swipe left gesture on the element.
 
         Args:
             percent: Swipe distance as percentage of element width (default: 0.75).
             speed: Swipe speed in pixels per second (default: 5000).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.swipe(direction="left", percent=percent, speed=speed)
+        return self.swipe(direction="left", percent=percent, speed=speed, strategy=strategy)
 
-    def swipe_right(self, percent: float = 0.75, speed: int = 5000) -> Element:
+    def swipe_right(
+        self,
+        percent: float = 0.75,
+        speed: int = 5000,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Perform a swipe right gesture on the element.
 
         Args:
             percent: Swipe distance as percentage of element width (default: 0.75).
             speed: Swipe speed in pixels per second (default: 5000).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.swipe(direction="right", percent=percent, speed=speed)
+        return self.swipe(direction="right", percent=percent, speed=speed, strategy=strategy)
 
     @fail_safe_element()
-    def swipe(self, direction: str, percent: float = 0.75, speed: int = 5000) -> Element:
+    def swipe(
+        self,
+        direction: str,
+        percent: float = 0.75,
+        speed: int = 5000,
+        strategy: GestureStrategy = GestureStrategy.AUTO,
+    ) -> Element:
         """Perform a swipe gesture on the element.
 
         Args:
             direction: Swipe direction ("up", "down", "left", "right").
             percent: Swipe distance as percentage of element size (default: 0.75).
             speed: Swipe speed in pixels per second (default: 5000).
+            strategy: Gesture execution strategy (W3C_ACTIONS, MOBILE_COMMANDS, AUTO).
 
         Returns:
             Element: Self for method chaining.
 
         """
-        return self.gestures.swipe(direction, percent, speed)
+        return self.gestures.swipe(direction, percent, speed, strategy)
 
     # ------------------------ properties ------------------------
 
@@ -1193,7 +1335,7 @@ class Element(ElementBase):
 
     # ------------------------------- waiting -------------------------------
 
-    @fail_safe_element()
+    @fail_safe_element_check()
     def wait(
         self,
         timeout: int = 10,
@@ -1213,7 +1355,7 @@ class Element(ElementBase):
         """
         return self.waiting.wait(timeout, poll_frequency=poll_frequency, return_bool=return_bool)
 
-    @fail_safe_element()
+    @fail_safe_element_check()
     def wait_visible(
         self,
         timeout: int = 10,
@@ -1237,7 +1379,7 @@ class Element(ElementBase):
             return_bool=return_bool,
         )
 
-    @fail_safe_element()
+    @fail_safe_element_check()
     def wait_clickable(
         self,
         timeout: int = 10,
@@ -1301,7 +1443,7 @@ class Element(ElementBase):
         """
         return self.waiting.wait_for_not_visible(timeout, poll_frequency, return_bool)
 
-    @fail_safe_element()
+    @fail_safe_element_check()
     def wait_for_not_clickable(
         self,
         timeout: int = 10,
